@@ -8,7 +8,7 @@ from colorama import *
 from datetime import datetime
 def names(email, password):
     try:
-        text = login_acc.login(email, password)
+        text = login_acc(email, password)
         token = text["access_token"]
 
         headers = {"Content-type": "application/json", "Authorization": "Bearer " + token}
